# vim: set ts=4 sw=4 et:
#
# spec file for package patool
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           patool
Version:        1.12
Release:        2.9
Summary:        Portable Command Line Archive File Manager
License:        GPL-3.0-or-later
Group:          Productivity/Archiving/Compression
URL:            https://github.com/wummel/patool
Source:         https://github.com/wummel/patool/archive/upstream/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  bash-completion
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildArch:      noarch

%description
patool is a portable command line archive file manager. Various archive types
can be created, extracted, tested and listed by patool.
The advantage of patool is its simplicity in handling archive files without
having to remember a myriad of programs and options.
The archive format is determined by the file(1) program and as a fallback by
the archive file extension.

patool supports 7z (.7z), ACE (.ace), ALZIP (.alz), AR (.a), ARC (.arc), ARJ
(.arj), BZIP2 (.bz2), CAB (.cab), compress (.Z), CPIO (.cpio), DEB (.deb), GZIP
(.gz), LRZIP (.lrz), LZH (.lha, .lzh), LZIP (.lz), LZMA (.lzma), LZOP (.lzo),
RPM (.rpm), RAR (.rar), TAR (.tar), XZ (.xz), and ZIP (.zip, .jar) formats.

It relies on helper applications to handle those archive formats.

%package bash-completion
Summary:        Bash Completion for patool
Group:          Productivity/Archiving/Compression
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
This package contains bash completion for patool, a portable command line
archive file manager.

%prep
%setup -q -n patool-upstream-%{version}

%build
%python3_build

%install
%python3_install
%fdupes %{buildroot}
install -Dpm 0644 patool.bash-completion \
  %{buildroot}%{_datadir}/bash-completion/completions/%{name}

%files
%doc COPYING doc/*.txt
%{_bindir}/patool
%{python3_sitelib}/*
%{_mandir}/man1/patool.1%{ext_man}

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%changelog
* Fri May 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Fix up dependency of -bash-completion subpackage:
  + Require the main package. The bash completion is useless
    without the application.
  + Supplement it against bash-completion, not against bash.
* Thu Nov 16 2017 mpluskal@suse.com
- Update to version 1.12:
  * Lots of changes - see provided changelog.txt
- Cleanup spec file with spec-cleaner
- Switch to python3
* Mon Apr  8 2013 pascal.bleser@opensuse.org
- update to 1.1:
  * Add support for zopfli, Googles new zlib compressor
  * Fix an error repacking compressed tar archives with 7z
- changes from 1.0:
  * Add support for searching in archive contents
  * Add support for ISO image handling
  * Allow multiple --verbose options to increase program output
  * Fixed Python lzma archive handling
  * Fixed lzop, lrzip and rzip archive handling
  * Fixed Python 3.x support
- changes from 0.19:
  * Support the lzma module in Python >= 3.3
  * Optimize repacking of archives with the same format
* Tue Dec 18 2012 pascal.bleser@opensuse.org
- update to 0.18:
  * Fixed unadf archive listing
  * Added support for Python 3.x
  * Use importlib to find program modules and depend on Python >= 2.7
  * Added support for archmage and chmlib handling CHM (.chm) archives
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 0.17:
  * Added support for Monkey's Audio Compressor handling APE (.ape) archives.
  * Added support for shorten handling SHN (.shn) archives.
  * Added support for flac handling FLAC (.flac) archives.
  * Added support for the BSD cpio and tar programs.
  * Added support for lhasa handling LZH (.lzh, .lha) archives.
  * Added support for lcap handling CAB (.cab) archives.
  * Added support for shar handling SHAR (.shar) shell archives.
  * Added support for unadf handling ADF (.adf) amiga disk archives.
  * Removed support for orange handling self-extracting installers.
  * Generate standalone Windows .exe and Linux .rpm installer.
  * Initialize the internal MIME database correct on all platforms.
  * Improved option compatibility for the ar, cpio and tar programs.
  * Rename the temporary output directory if it contains multiple files. The
    name is the archive name without extension, which is more readable than a
    random filename "UnpackXyz".
  * Require and use Python >=2.5
- changes from 0.16:
  * Document the --outdir option for the extract command.
  * Added convenience library function to handle archives.
  * Added support for the lbzip2 program handling BZIP2 archives.
  * Added support for the plzip program handling LZIP archives.
  * Prevent overwriting files with repack.
  * Support extraction of BZIP2 (.bz2) files with the Python bz2 module.
  * Support extraction of GZIP (.gz) files with the Python gzip module.
  * Support extraction of ZIP (.zip) files with the Python zipfile module.
  * Support extraction of TAR (.tar) files with the Python tarfile module.
* Sat Apr 14 2012 pascal.bleser@opensuse.org
- update to 0.15:
  * print help when unknown options are given
  * print error when archive files do not exist
  * added support for the pigz program handling GZIP archives
- changes from 0.14:
  * handle CRX (.crx) files as ZIP archives: they have garbage at
    the beginning of the file, but some unzip programs can cope with
    that
  * the xz program supports listing of XZ archives: adjust the
    configuration accordingly
* Wed Jan 26 2011 pascal.bleser@opensuse.org
- update to 0.13:
  * adds support for DMS (.dms) files
  * fixes a bug in extracting cpio archives
  * improved MIME type detection
* Thu Jan 20 2011 pascal.bleser@opensuse.org
- split out bash completion into patool-bash-completion, as it requires the
  package "bach-completion"
- fixes bnc#661851 (bash-completion issues error for missing patool pkg which
  is present)
* Sun Nov 21 2010 pascal.bleser@opensuse.org
- reformatted spec file
- update to 0.12:
  * archive commands are now printed on the console before running them
  * a RAR extraction bug has been fixed
* Wed Oct  6 2010 pascal.bleser@opensuse.org
- update to 0.11:
  * adds support for the "7za" archive program
* Sat Apr 10 2010 pascal.bleser@opensuse.org
- initial package (0.10)
